@@ -94,7 +94,7 @@ class PrestaShopWebService(object):
     MAX_COMPATIBLE_VERSION = '1.7.8.999'
 
     def __init__(self, api_url, api_key, debug=False, session=None,
-                 verbose=False, custome_headers=None):
+                 verbose=False, custom_headers=None):
         """
         Create an instance of PrestashopWebService.
 
@@ -143,13 +143,13 @@ class PrestaShopWebService(object):
 
         if session is None:
             self.client = requests.Session()
-            self.client.headers.update(custome_headers)
+            if custom_headers:
+                self.client.headers.update(custom_headers)
         else:
             self.client = session
 
         if not self.client.auth:
             self.client.auth = (api_key, '')
-        self.custome_headers = custome_headers
 
     def _parse_error(self, xml_content):
         """Take the XML content as string and extract the PrestaShop error.
@@ -247,8 +247,6 @@ class PrestaShopWebService(object):
 
         request_headers = self.client.headers.copy()
         request_headers.update(add_headers)
-        if self.custome_headers:
-            request_headers.update(self.custome_headers)
 
         if self.verbose:
             currentlevel = HTTPConnection.debuglevel
